@@ -2,7 +2,7 @@
 
 from typing import List, Optional, Set
 
-from gpt_index.indices.keyword_table.utils import simple_extract_keywords
+from llama_index.indices.keyword_table.utils import simple_extract_keywords
 
 
 def mock_tokenizer(text: str) -> List[str]:
