@@ -1,6 +1,5 @@
 """Test prompts."""
 
-from typing import List
 from unittest.mock import MagicMock
 
 import pytest
@@ -9,7 +8,7 @@ from langchain.chains.prompt_selector import ConditionalPromptSelector
 from langchain.chat_models.base import BaseChatModel
 from langchain.chat_models.openai import ChatOpenAI
 
-from gpt_index.prompts.base import Prompt
+from llama_index.prompts.base import Prompt
 
 
 class TestLanguageModel(ChatOpenAI):
@@ -21,54 +20,25 @@ def is_test(llm: BaseChatModel) -> bool:
     return isinstance(llm, TestLanguageModel)
 
 
-class TestPrompt(Prompt):
-    """Test prompt class."""
-
-    input_variables: List[str] = ["text", "foo"]
-
-
-def test_prompt_validate() -> None:
-    """Test prompt validate."""
-    # assert passes
-    prompt_txt = "hello {text} {foo}"
-    TestPrompt(prompt_txt)
-
-    # assert fails (missing required values)
-    with pytest.raises(ValueError):
-        prompt_txt = "hello {tmp}"
-        TestPrompt(prompt_txt)
-
-    # assert fails (extraneous values)
-    with pytest.raises(ValueError):
-        prompt_txt = "hello {text} {foo} {text2}"
-        TestPrompt(prompt_txt)
-
-
 def test_partial_format() -> None:
     """Test partial format."""
     prompt_txt = "hello {text} {foo}"
-    prompt = TestPrompt(prompt_txt)
+    prompt = Prompt(prompt_txt)
 
     prompt_fmt = prompt.partial_format(foo="bar")
 
-    assert isinstance(prompt_fmt, TestPrompt)
+    assert isinstance(prompt_fmt, Prompt)
     assert prompt_fmt.format(text="world") == "hello world bar"
 
 
 def test_from_prompt() -> None:
     """Test new prompt from a partially formatted prompt."""
-
-    class TestPromptTextOnly(Prompt):
-        """Test prompt class."""
-
-        input_variables: List[str] = ["text"]
-
     prompt_txt = "hello {text} {foo}"
-    prompt = TestPrompt(prompt_txt)
+    prompt = Prompt(prompt_txt)
     prompt_fmt = prompt.partial_format(foo="bar")
 
-    prompt_new = TestPromptTextOnly.from_prompt(prompt_fmt)
-    assert isinstance(prompt_new, TestPromptTextOnly)
+    prompt_new = Prompt.from_prompt(prompt_fmt)
+    assert isinstance(prompt_new, Prompt)
 
     assert prompt_new.format(text="world2") == "hello world2 bar"
 
@@ -77,25 +47,17 @@ def test_from_langchain_prompt() -> None:
     """Test from langchain prompt."""
     prompt_txt = "hello {text} {foo}"
     prompt = PromptTemplate(input_variables=["text", "foo"], template=prompt_txt)
-    prompt_new = TestPrompt.from_langchain_prompt(prompt)
+    prompt_new = Prompt.from_langchain_prompt(prompt)
 
-    assert isinstance(prompt_new, TestPrompt)
+    assert isinstance(prompt_new, Prompt)
     assert prompt_new.prompt == prompt
     assert prompt_new.format(text="world2", foo="bar") == "hello world2 bar"
 
-    # test errors if langchain prompt input var doesn't match
-    with pytest.raises(ValueError):
-        prompt_txt = "hello {text} {foo} {tmp}"
-        prompt = PromptTemplate(
-            input_variables=["text", "foo", "tmp"], template=prompt_txt
-        )
-        TestPrompt.from_langchain_prompt(prompt)
-
     # test errors if we specify both template and langchain prompt
     with pytest.raises(ValueError):
         prompt_txt = "hello {text} {foo}"
         prompt = PromptTemplate(input_variables=["text", "foo"], template=prompt_txt)
-        TestPrompt(template=prompt_txt, langchain_prompt=prompt)
+        Prompt(template=prompt_txt, langchain_prompt=prompt)
 
 
 def test_from_langchain_prompt_selector() -> None:
@@ -111,8 +73,8 @@ def test_from_langchain_prompt_selector() -> None:
 
     test_llm = MagicMock(spec=TestLanguageModel)
 
-    prompt_new = TestPrompt.from_langchain_prompt_selector(test_prompt_selector)
-    assert isinstance(prompt_new, TestPrompt)
+    prompt_new = Prompt.from_langchain_prompt_selector(test_prompt_selector)
+    assert isinstance(prompt_new, Prompt)
     assert prompt_new.prompt == prompt
     assert prompt_new.format(text="world2", foo="bar") == "hello world2 bar"
     assert (
@@ -136,4 +98,4 @@ def test_from_langchain_prompt_selector() -> None:
         test_prompt_selector = ConditionalPromptSelector(
             prompt=prompt, conditionals=([is_test], [prompt_2])
         )
-        prompt_new = TestPrompt.from_langchain_prompt_selector(test_prompt_selector)
+        prompt_new = Prompt.from_langchain_prompt_selector(test_prompt_selector)
